angular.module('starter.controllers')

//====================================
// Account Controller
//====================================
.controller('AccountCtrl', function($scope,$state,$filter,$ionicLoading,$ionicModal,
																		$timeout,
																		$ionicHistory,
																		LocalStorage,
																		Account,
																		Social,
																		Airstation,
																		ReportManager,
																		Datastore,
																		Utility,
																		KBToast,
																		KBStore) {

	

	//--------------------------------
	// Function
	//--------------------------------
	var RefreshProfileData = function(){
		console.log("Refresh Profile from server");
		Account.getProfile(
			function(data, status, headers, config){
				//Success Callback
				if(status == 200){
					$scope.account.profile = data[0];

					//Get time zone from location
					Utility.AdjustBirthByLocation($scope.account.profile);
					
					LocalStorage.setItem('user_id', $scope.account.profile.id);
					LocalStorage.setObject('profile',$scope.account.profile);

				}//end of status 200
				else{
					KBToast.error('Fail to get profile data');
					KBToast.debug(status +' ' + data);
				}
				$scope.refresh = false;

			},//end of get profile success
			function(data, status, headers, config){
				//Fail Callback
				KBToast.error('Fail to get profile data');
				KBToast.debug(status +' ' + data);
				if(status == 401){
					console.log('Get profile Unauthorized');
				}

				$scope.refresh = false;
			}
		);
	}


	//--------------------------------
	// Event
	//--------------------------------
	$scope.$watch('refresh', function(newVal, oldVal){
		if(newVal !== oldVal && newVal === false){
			$scope.$broadcast('scroll.refreshComplete');
		}
	});

	//--------------------------------
	// Valuable Define 
	//--------------------------------
	$scope.refresh = false;
	$scope.editData = {
		id: null,
		real_name: null,
		birthday: null,
		location: null,
		birth: null,
	};

	$scope.account.is_social_account = LocalStorage.getItem('is_social_account');

	$scope.map = Datastore.getGoogleMapSetting();

	$scope.showError = false;
	$scope.showDateInvalid = false;

	//-------------------------
	// DateTime Picker
	//-------------------------
	$scope.OpenNativeDatePicker = function(){
		

		var options = {
			date: new Date(moment($scope.editData.birth.date).format('MM/DD/YYYY')),
			mode: 'date',
			minDate: new Date(moment($scope.editData.birth.min).format('MM/DD/YYYY')),
			maxDate: new Date(moment($scope.editData.birth.max).format('MM/DD/YYYY')),
		};

		
		datePicker.show(options, function(datetime){
			//alert("date result " + datetime); 
			if (datetime !== null && typeof datetime != 'undefined') {

				//valid
				newDateTime = moment(datetime);
				minDateTime = moment($scope.editData.birth.min);
				maxDateTime = moment($scope.editData.birth.max);

				if(newDateTime <= maxDateTime && newDateTime >= minDateTime){
					$scope.showDateInvalid = false;
				} else if(newDateTime > maxDateTime && !$scope.account.profile.is_staff){
					$scope.showDateInvalid = true;
					//alert("Invalid Date " + datetime); 
				} else {
					$scope.showDateInvalid = false;
				}

				$scope.editData.birth.date = new Date(moment(datetime).format('MM/DD/YYYY'));

				$scope.$apply();
			}
		});

	}

	$scope.OpenNativeTimePicker = function(){
		

		var options = {
			date: new Date(moment($scope.editData.birth.time).format('MM/DD/YYYY HH:mm')),
			mode: 'time',
		};

		
		datePicker.show(options, function(datetime){
			//alert("date result " + datetime);  
			if (datetime !== null && typeof datetime != 'undefined') {
				$scope.editData.birth.time = new Date(moment(datetime).format('MM/DD/YYYY HH:mm'));
				$scope.$apply();
			}
		});

	}

	//--------------------------------
	// UI function
	//--------------------------------
	$scope.goState = function(state) {
		console.log('account edit state');
		$state.go(state);
	}

	$scope.doRefresh = function(){
		console.log('Do doRefresh')
		$scope.refresh = true;
		RefreshProfileData();
	}

	// ------------------------------------
	// Delete pop up modal function
	// ------------------------------------
	$ionicModal.fromTemplateUrl('templates/modal/logout-popup.html', {
		scope: $scope,
		animation: 'scale-in'
	}).then(function(modal) {
		$scope.logoutModal = modal;
	})

	$scope.openLogoutModal = function() {
		$scope.logoutModal.show();
	}

	$scope.closeLogoutModal = function() {
		$scope.logoutModal.hide();
	}

	$scope.$on('$destroy', function() {
		$scope.logoutModal.remove();
	})

	$scope.OnFBConnect = function(){
		//1. Login facebook
		Social.loginFacebook(function(data){
			//Facebook Plugin Login Success
			$ionicLoading.show({template:'<i class="icon ion-ios7-reloading font-xxl"></i>'});
			Account.connectSocialAccount('facebook',data.id,
				function(data, status, headers, config){
					$ionicLoading.hide();
					if(status == 200){
						$scope.account.profile.social_account = data.social_account
						//KBToast.success($scope.t.connect_fb_success);
					}
					else{
						KBToast.debug(status + '' + data);
						KBToast.error($scope.t.connect_fb_fail);
					}
				},
				function(data, status, headers, config){
					$ionicLoading.hide();
					KBToast.debug(status + '' + data);
					KBToast.error($scope.t.connect_fb_fail);
				}
			);
		},
		function(data){
			//Facebook Plugin Login FAil
			KBToast.debug(status + '' + data);
			KBToast.error($scope.t.connect_fb_fail);
		});
	}

	$scope.OnFBDisconnect = function(){
		$ionicLoading.show({template:'<i class="icon ion-ios7-reloading font-xxl"></i>'});
		Account.disconnectSocialAccount('facebook',
			function(data, status, headers, config){
				$ionicLoading.hide();
				console.log(data);
				if(status == 200){
					$scope.account.profile.social_account = data.social_account
				}
				else{
					KBToast.debug(status + '' + data);
					KBToast.error($scope.t.disconnect_fb_fail);
				}
			},
			function(data, status, headers, config){
				$ionicLoading.hide();
				KBToast.debug(status + '' + data);
				KBToast.error($scope.t.disconnect_fb_fail);
			}
		);
	}
})

//====================================
// Account Edit Controller
//====================================
.controller('AccountEditCtrl', function($scope,
										$state,
										$filter,
										$ionicLoading,
										$ionicHistory,
										Account,
										LocalStorage,
										Airstation,
										Datastore,
										Utility,
										KBToast){
	$scope.editData = {}; 
	$scope.editData.username = null;
	$scope.account.is_social_account = LocalStorage.getItem('is_social_account');

	$scope.$on('$ionicView.beforeEnter', function () {
		console.log("AccountEditCtrl beforeEnter");
		$scope.editData.username = $scope.account.profile.username;
		console.log("is_social_account : ", $scope.account.is_social_account + " " + $scope.account.profile.username);
	});

	var RefreshProfileData = function() {
		console.log("Refresh Profile from server");
		Account.getProfile(
			function(data, status, headers, config){
				//Success Callback
				if(status == 200){
					$scope.account.profile = data[0];
					LocalStorage.setObject('profile',$scope.account.profile);

				}//end of status 200
				else{
					KBToast.error('Fail to get profile data');
					KBToast.debug(status +' ' + data);
				}
				$scope.refresh = false;

			},//end of get profile success
			function(data, status, headers, config){
				//Fail Callback
				KBToast.error('Fail to get profile data');
				KBToast.debug(status +' ' + data);
				if(status == 401){
					console.log('Get profile Unauthorized');
				}

				$scope.refresh = false;
			}
		);
	}

	$scope.updateUsername = function() {
	
		if (typeof $scope.account.is_social_account === "undefined" || $scope.account.is_social_account === null || !$scope.account.is_social_account) {
			if (!$scope.checkEmail($scope.editData.username)) {
				KBToast.error($scope.t.msg_fill_valid_email);
				return;
			}
		}

		$ionicLoading.show({template: '<i class="fa fa-circle-o-notch fa-spin fa-2x fa-fw"></i>'});

		var formdata = {
			username: $scope.editData.username
		};

		Airstation.put(
			{
				app:'account',
				resource:'update',
				id:$scope.account.profile.id,
			},
			formdata,
			function(rpn_data){

				if (window.ga) {
					window.ga.trackView('/app/account/edit/success');
				}
				$scope.refresh = true;
				RefreshProfileData();
				$ionicHistory.goBack();
				$ionicLoading.hide();
			},function(error){
				//2.1 Fail Handle
				$ionicLoading.hide();
				if (error.data === "username already exist") {
					KBToast.error($scope.t.Username_exist);	
				} 
				else {
					KBToast.error($scope.t.update_profile_fail);
				}
				if (window.ga) {
					window.ga.trackView('/app/account/edit/fail');
				}
			}
		);

	}

})

