
angular.module('kolorbox.kbstore', ['ng','ngResource'])

/*
======================================
Kolorbox Store Directive component
======================================
*/
.directive('itemCheckoutController',function() {

	var controller = ['$scope','KBStore', function ($scope,KBStore) {

		$scope.IsValidItem = false;

		//1. Chcek Item is valid
		$scope.item = KBStore.getItem($scope.itemId);
		if($scope.item != null)
		{
			$scope.IsValidItem = true;
		}

		//2. Get available payment service
		$scope.paymentServices = KBStore.getAvailableServices();


		$scope.checkoutItem = function (service) {
			KBStore.checkoutItem(service,$scope.itemId,$scope.success,$scope.fail);
		};
	}]
				
	return {
			restrict: 'EA', //Default in 1.3+
			scope: {
				itemId: '@',
				success: '&',
				fail: '&',
			},
			controller: controller,
			templateUrl: 'templates/KBStore-Item-Checkout.html'
	};
})

/*
======================================
Kolorbox Store
======================================
*/
.factory('KBStore',function($http,$ionicLoading,Airstation,PayPal,IAP) {
	var products = [];
	var paymentServices = [];

	var service = {
		init: init,
		initNativeService: initNativeService,
		getProduct: getProduct,
		getAvailableServices: getAvailableServices,
		checkoutItem: checkoutItem,
	};

	function init(){
		var iap_icon_img = "";
		var iap_title = "";
		var iap_name = "";

		if(ionic.Platform.isIOS()){
			iap_icon_img = "img/applestore_icon.png";
			iap_title = "App Store";
			iap_name = 'appstore';
		}
		else if(ionic.Platform.isAndroid()){
			iap_icon_img = "img/googleplay_icon.png";
			iap_title = "Google Play";
			iap_name = 'googleplay';
		}

		//1. Perpare Payment Service info
		paymentServices = [
			{
				id: 0,
				name: 'stripe',
				bReady: g_stripe_enable,
				title: 'Stripe',
				iconImg: 'https://stripe.com/img/about/logos/logos/black.png',
				iconWidth: 150,
				merchantID_production: g_stripe_production_publish_key,
				merchantID_sandbox: g_stripe_sandbox_publish_key,
			},
			{
				id: 1,
				name: 'paypal',
				bReady: false,
				title: 'PayPal',
				iconImg: 'img/paypal_icon.png',
				iconWidth: 280,
				merchantID_production: g_paypal_production_key,
				merchantID_sandbox: g_paypal_sandbox_key,
			},
			{
				id: 2,
				name: 'iap',
				iap_name:iap_name,
				bReady: false,
				title: iap_title,
				iconImg: iap_icon_img,
				iconWidth: 280,
				merchantID_production: '',
				merchantID_sandbox: '',
			},
		];

		//2.
		products = [
			{
				//for android
				//id: 'com.newageideas.hd.personalreport',

				//for ios
				//id: 'com.newageideas.tier7.personalreport',

				id: g_product_name,
				title: 'Human Design Report',
				desc: 'Human Design Report',
				gateways:[
					{
							name:'iap',
							available:false,
							price_str: '$0.00'
					},
					{
							name:'paypal',
							price: 4.99,
							price_str: 'US$4.99',
							currency: 'USD',
							available:true,
					}
				]
			},
		];	
	}

	function initNativeService(){
		//init paypal
		if(window.PayPalMobile){
			if((ionic.Platform.isIOS() && g_paypal_ios_enable) || (ionic.Platform.isAndroid() && g_paypal_android_enable)){
				console.log('init paypal')
				var paypal = getServiceByName('paypal');
				if(paypal != null){
					PayPal.init(g_bUseSandbox,
						paypal.merchantID_production,
						paypal.merchantID_sandbox,
						function(data){
							paypal.bReady = true;
						}
					);
				}
			}
		}
				
		if(g_iap_enable == true &&	window.store){
			console.log('init IAP')
			var iap = getServiceByName('iap');
			console.log('iap',iap)
			IAP.init(iap.iap_name,
				function(data){
			 		//IAP Store Ready Callbacl
					iap.bReady = true;
				},
				function(iap_item){
					console.log('IAP Product Update:',iap_item.id,iap_item.state,iap_item.valid,iap_item.canPurchase)
					//IAP Product state update
					product = getProduct(iap_item.id);
					if(product != null){
						product.gateways[0].available = iap_item.valid;
						product.gateways[0].price_str = iap_item.price;
						//console.log(product);
				 	}
				}
			);
			IAP.registerProducts(products);
		}
	}

	function getProduct(id){
		for (var i=0; i < products.length; i++){
			if(products[i].id == id){
				return products[i];
			}
		}
		return null;
	}

	function getAvailableServices(){
		return paymentServices;
	}

	function getServiceByName(serviceName){
		for (var i=0; i < paymentServices.length; i++){
			if(paymentServices[i].name == serviceName){
				return paymentServices[i];
			}
		}
		return null;
	}

	function getPaymentDetail(product,serviceName){
		for (var i=0; i < product.gateways.length; i++){
			if(product.gateways[i].name == serviceName){
				return product.gateways[i];
			}
		}
		return null;
	}

	//Checkout function
	function checkoutItem(service_id,ga_event_label,product_id,successCallback,failCallback,cancelCallback){

		//Get service
		var paymentService = paymentServices[service_id]
		console.log("Checkout " + product_id + " by " + paymentService.name);

		//Get product detail
		var product = getProduct(product_id);

		if(paymentService.name == "stripe"){
			checkoutByStripe(product,ga_event_label,successCallback,failCallback);
		}
		else if(paymentService.name == "paypal"){
			checkoutByPayPal(product,ga_event_label,successCallback,failCallback,cancelCallback);
		}
		else if(paymentService.name == "iap"){
			checkoutByIAP(product,ga_event_label,successCallback,failCallback,cancelCallback);
		}
	}

	function checkoutByPayPal(product,ga_event_label,successCallback,failCallback,cancelCallback){

		var paymentDetail = getPaymentDetail(product,"paypal")

		if(paymentDetail != null){
			PayPal.makePayment(ga_event_label,paymentDetail.price,paymentDetail.currency,product.desc,successCallback,failCallback,cancelCallback);
		}
		else{
			failCallback('paypal');
		}
	}

	function checkoutByIAP(product,ga_event_label,successCallback,failCallback,cancelCallback){
		IAP.makePayment(ga_event_label,product.id,successCallback,failCallback,cancelCallback);
	}

	function checkoutByStripe(product,ga_event_label,successCallback,failCallback){
		//1. Prepare data
		var token = function (res) {
			$ionicLoading.show({template:'<i class="icon ion-ios7-reloading font-xxl"></i>'});
				 	
			var payment_data ={
				product_id : product.id,
				price : product.price,
				currency : product.currency,
				service_id : 'stripe',
				stripeToken : res.id
			};

			console.log(payment_data);

			//Make Payment charge request
			Airstation.post({resource:'hdapp/payment'}, payment_data,
				function(resp_data){
					console.log(resp_data);
					$ionicLoading.hide();

					if(resp_data.state == "success"){
						if(successCallback!= null){
							successCallback();
						}
					}
					else{
						if(failCallback != null){
							failCallback();
						}	
					}

				},
				function(error) {
					$ionicLoading.hide();
					if(failCallback != null){
						failCallback();
					}
				}
			);
		};// end of token

		var merchantID = "";
		var stripe = getServiceByName('stripe');
		if(g_bUseSandbox == true)
		{
			merchantID = stripe.merchantID_sandbox;
		}
		else
		{
			merchantID = stripe.merchantID_production;
		}

		StripeCheckout.open({
			key: merchantID,
			address: false,
			amount: product.price * 100, /** expects an integer **/
			currency: product.currency,
			name: product.title,
			description: '',
			panelLabel: 'Checkout',
			token: token
		});
	}

	return service;
})

/*
======================================
In App Purchase Controller
======================================
*/

.factory('IAP',function(KBToast){

	var readyCallback = null;
	var productUpdateCallback = null;
	var purchaseSccuessCallBack = null;
	var purchaseFailCallBack = null;
	var purchaseCancelCallBack = null;
	var ga_event_label = '';
	var iap_name = '';


	var bIsReady = "unknown";

	var service = {
		init: init,
		registerProducts: registerProducts,
		isReady: isReady,
		makePayment: makePayment,
	};

	function init(name,ready,update){

		console.log('iap init: ',name)
		readyCallback = ready;
		productUpdateCallback = update;
		iap_name = name;

		if (!window.store) {
			bIsReady = false;
			return;
		}

		store.ready(function() {
			bIsReady = true;
			readyCallback();
		});

		store.error(function(error) {
			KBToast.debug('ERROR ' + error.code + ': ' + error.message);
			bIsReady = false;

			//Special handle on purchase fail due to store fail
			if (purchaseFailCallBack != null){
					purchaseFailCallBack();
			}

			purchaseSccuessCallBack = null;
			purchaseFailCallBack = null;
		});
	}

	function registerProducts(products){

		console.log('registerProducts');
		for (var i=0; i < products.length; i++){
			var product = products[i];

			store.register({
				id:		product.id,
				alias: product.name,
				type:	 store.CONSUMABLE
			});

			store.when(product.id).updated(function(p) {
				//console.log(p);
				productUpdateCallback(p);
			});

			store.when(product.id).approved(function(p) {
				//console.log('Product approved');
				p.finish();
				purchaseSccuess(p);
			});

			store.when(product.id).cancelled(function(p) {
				//console.log('Product cancelled');
				purchaseCancel(p);
			});

			store.when(product.id).error(function(p) {
				//console.log('Product error');
				purchaseFail(p);
			});
		}
		store.refresh();
	}

	function isReady(){
		return bIsReady;
	}

	function makePayment(label,id,successCallback,failCallback,cancelCallback){
		purchaseSccuessCallBack = successCallback;
		purchaseFailCallBack = failCallback;
		purchaseCancelCallBack = cancelCallback;
		ga_event_label = label;
		store.order(id);
	}

	//--------------------------------
	// private function
	//--------------------------------
	function purchaseSccuess(p){
		console.log('IAP Purchase Sccuess',p)
		console.log('IAP Purchase Sccuess Transaction: ',p.transaction)

		/*
		for(key in p.transaction ){
			console.log(key,p.transaction[key]);
		}*/
		
		if (purchaseSccuessCallBack != null){
			purchaseSccuessCallBack(iap_name,p.transaction);
		}
		purchaseSccuessCallBack = null;
		purchaseFailCallBack = null;
		purchaseCancelCallBack = null;
	}

	function purchaseFail(p){
		if (purchaseFailCallBack != null){
			purchaseFailCallBack(iap_name);
		}
                                                                                                      
		purchaseSccuessCallBack = null;
		purchaseFailCallBack = null;
		purchaseCancelCallBack = null;
	}

	function purchaseCancel(p){
		if (purchaseCancelCallBack != null){
			purchaseCancelCallBack(iap_name);
		}

		purchaseSccuessCallBack = null;
		purchaseFailCallBack = null;
		purchaseCancelCallBack = null;
	}

	return service;
})


/*
======================================
PayPal Controller
======================================
*/
.factory('PayPal', function ($q, $location,$ionicPlatform,$ionicLoading,$window,$rootScope,$sce) {

	var successCallback = null;
	var failCallback = null;
	var cancelCallback = null;
	var ga_event_label = '';
	var readyCallback = null;
	var bIsReady = "unknown";
	var UseSandbox = false;

	var service = {
		init: init,
		makePayment: makePayment,
		isReady: isReady
	};

	function init(sandbox,production_id,Sandbox_id,ready){
		UseSandbox = sandbox;
		readyCallback = ready;
		bIsReady = false;
		var clientIDs = {
			"PayPalEnvironmentProduction": production_id,
			"PayPalEnvironmentSandbox": Sandbox_id
		};

		PayPalMobile.init(clientIDs, onPayPalMobileInit); 
	}

	function makePayment(ga_event_label,price,currency,desc,success,fail,cancel) {

		ga_event_label = ga_event_label;
		successCallback = success;
		failCallback = fail;
		cancelCallback = cancel;

		if(bIsReady == true)
		{
				console.log('paypal makePayment');
				PayPalMobile.renderSinglePaymentUI(createPayment(price,currency,desc), onSuccesfulPayment, onUserCanceled);
		}
		else
		{
			/*
			//Prepare paypal payment complete redirect link
			var redirect_link = $location.absUrl() + "?date=" + report_date + "&paid=1";
			console.log(redirect_link);
			var data = {
					redirectUrl: 'https://www.sandbox.paypal.com/cgi-bin/webscr',
					redirectMethod: 'POST',
					redirectData: {
							'cmd': '_cart',
							'business': 'payment_sandbox@kolorbox.com',
							'return' : redirect_link,
							'upload': '1',
							'rm': '2',
							'charset': 'utf-8',
							'item_number_1': 'RPT',
							'item_name_1': 'Human Design Report',
							'quantity_1': '1',
							'amount_1': '35.00',
					}
			}
			console.log('fire event');
			data.redirectUrl = $sce.trustAsResourceUrl(data.redirectUrl);
			$ionicLoading.show({template:'<i class="icon ion-ios7-reloading font-xxl"></i>'});
			$rootScope.$broadcast('paypal_payment_event', data);
			*/
		}
	}

	function isReady(){
			return bIsReady;
	}

	//-------------------------------
	// CallBack Function
	//-------------------------------
	function onPrepareRender(){
		bIsReady = true;
		if(readyCallback != null){
			readyCallback('paypal ready');
		}
	}


	function onSuccesfulPayment(payment) {
		console.log('paypal onSuccesfulPayment');
		console.log(payment);
		try{
			if(payment["response"]["state"] == "approved"){
				if(successCallback != null){

					//example
					//{"response":{"create_time":"2015-04-24T05:02:04Z","id":"PAY-3DP90335TM3658613KU444TA","state":"approved","intent":"sale"},"client":{"paypal_sdk_version":"2.8.2","environment":"sandbox","platform":"iOS","product_name":"PayPal iOS SDK"},"response_type":"payment"}
					console.log('paypal payment success');
					successCallback('paypal',payment.response);								
				}
			}
			else{
				console.log('paypal payment fail');
				if(failCallback != null){
					failCallback('paypal');	 
				}
			}
		}
		catch (e){
			console.log(e);
			if(failCallback != null){
				failCallback('paypal');	 
			}
		}

		successCallback = null;
		failCallback = null;
		cancelCallback = null
	}

	function onUserCanceled(result) {
		console.log('onUserCanceled');
		if(cancelCallback != null){
			cancelCallback('paypal');	 
		}

		successCallback = null;
		failCallback = null;
		cancelCallback = null
	}

	function onFuturePaymentAuthorization(authorization) {
		console.log("authorization: " + JSON.stringify(authorization, null, 4));
	}
		
	function createPayment(price,currency,desc) {
		// for simplicity use predefined amount
		var price_str = price.toString();
		var paymentDetails = new PayPalPaymentDetails(price_str, "0.00", "0.00");
		var payment = new PayPalPayment(price_str, currency,desc, "Sale", paymentDetails);
		return payment;
	}

	function configuration() {
		// for more options see `paypal-mobile-js-helper.js`
		var config = new PayPalConfiguration({merchantName: "My Test Shop", merchantPrivacyPolicyURL: "https://mytestshop.com/policy", merchantUserAgreementURL: "https://mytestshop.com/agreement"});
		return config;
	}

	function onPayPalMobileInit() {
		// must be called
		// use PayPalEnvironmentNoNetwork mode to get look and feel of the flow
		if(UseSandbox == true){
				PayPalMobile.prepareToRender("PayPalEnvironmentSandbox", configuration(), onPrepareRender);
		}
		else{
				PayPalMobile.prepareToRender("PayPalEnvironmentProduction", configuration(), onPrepareRender);
		}
	}

	return service;
})

.directive('paypalSubmitForm', ['$timeout', function($timeout) {
		return {
				replace: true,
				scope: {},
				template:'<form action="{{formData.redirectUrl}}" method="{{formData.redirectMethod}}">'+
								'<div ng-repeat="(key,val) in formData.redirectData">'+
									'<input type="hidden" name="{{key}}" value="{{val}}" />'+
								'</div>'+
						'</form>',
				link: function($scope, element, $attrs) {
					$scope.$on($attrs['event'], function(event, data) {
						$scope.formData = data;
						console.log('redirecting now!');
						$timeout(function() {
							$(element).submit();
						})
					})
				}
		}
}]);


