angular.module('starter.services', [])

/**
 * A simple example service that returns some data.
 */

.factory('LocalStorage',function($window){
	return {
		setItem: function(key, value) {
			$window.localStorage[key] = value;
		},
		getItem: function(key) {
			var value = $window.localStorage[key];
			if(typeof value === "undefined"){
				return null;
			}
			else{
				//special handle of boolen value
				if(value == 'true'){
					return true;
				}
				else if( value == 'false'){
					return false;
				}
				else if (value == 'null'){
					return null
				}
				else{
					return value;
				}
			} 
		},
		removeItem: function(key) {
			$window.localStorage.removeItem(key);
		},
		setObject: function(key, value) {
			$window.localStorage[key] = JSON.stringify(value);
		},
		getObject: function(key) {

			var value = $window.localStorage[key];
			if(typeof value === "undefined"){
				return null;
			}
			else{
				return JSON.parse(value);
			}
			//var value = JSON.parse($window.localStorage[key] || '{}');
		},
		removeObject: function(key) {
				$window.localStorage.removeItem(key);
		},

		clearUp: function(){
			for (index in $window.localStorage){
				$window.localStorage.removeItem(index);
			}
		},
	}
})

.factory('Datastore', function(LocalStorage) {
	var date =moment();
	var time =moment();
	var tz = '';
	var location = null;

	var personalReportList = LocalStorage.getObject('personalChart');
	var profile = null;
	var socialshare = {};
 
	var googleMap = {
			center : {
				lat: 0,
				lng: 0,
				zoom: 1
			},
			markers : {
				mark : {
					lat: 0,
					lng: 0,
					message: "",
					icon : {
										iconUrl: 'img/marker-icon-2x.png',
										iconSize:		 [25, 41], // size of the icon
										iconAnchor:	 [13, 41], // point of the icon which will correspond to marker's location
										popupAnchor:	[-3, -41] // point from which the popup should open relative to the iconAnchor
								}
				}
			},
			layers : {
				baselayers: {
					googleRoadmap: {
						name: 'Google Streets',
						layerType: 'ROADMAP',
						type: 'google',
						layerOptions: {
							"mapOptions": {
								"styles" :[
									{
										"stylers": [
											{
												"hue": "#ff1a00"
											},
											{
												"invert_lightness": true
											},
											{
												"saturation": -100
											},
											{
												"lightness": 33
											},
											{
												"gamma": 0.5
											}
										]
									},
									{
										"featureType": "water",
										"elementType": "geometry",
										"stylers": [
											{
											"color": "#2D333C"
											}
										]
									}
								]
							},
						},
					},
					/*
					openstreet: {
						name: 'OpenStreet',
						url: 'http://{s}.tile.osm.org/{z}/{x}/{y}.png',
						type: 'xyz',
					},
					googleTerrain: {
						name: 'Google Terrain',
						layerType: 'TERRAIN',
						type: 'google'
					},
					googleHybrid: {
						name: 'Google Hybrid',
						layerType: 'HYBRID',
						type: 'google'
					},
					mapbox_terrain: {
						name: 'Mapbox Terrain',
						url: 'http://api.tiles.mapbox.com/v4/{mapid}/{z}/{x}/{y}.png?access_token={apikey}',
						type: 'xyz',
						layerOptions: {
							apikey: 'pk.eyJ1IjoidGVycnlsYW0yMjciLCJhIjoibEpuSHM5TSJ9.qFOUHecbnp46uyNSHgkGAQ',
							mapid: 'terrylam227.1be70781',
							detectRetina : true,
						}
					},
					*/
				}
			},
			defaults : {
				scrollWheelZoom: false,
				dragging : false,
				doubleClickZoom: false,
				zoomControl : false,
				tileLayerOptions : {
					detectRetina : true,
				},
			},
		};

	return {
		setDate: function(data) {
			date = data;
		},
		getDate : function() {
			return date;
		},
		setTime: function(data) {
			time = moment(data, 'HH:mm');
		},
		getTime: function() {
			return time;
		},
		setTimezone: function(data) {
			tz = data;
		},
		getTimezone: function() {
			return tz;
		},
		setLocation: function(data) {
				location = data;
		},
		getLocation: function() {
				return location;
		},

		getGoogleMapSetting: function() {
			return googleMap;
		},

		//-----------------------------------
		// Personal Report List
		//-----------------------------------
		setPersonalReportList: function(data) {
			personalReportList = data;
			LocalStorage.setObject('personalChart',personalReportList);
		},
		getPersonalReportList: function() {
			return personalReportList;
		},
		addPersonalReport: function(data) {
			if(!personalReportList){
				personalReportList = [];
			}
			personalReportList.push(data);
			LocalStorage.setObject('personalChart',personalReportList);
		},
		delPersonalReport: function(id) {
			for (index in personalReportList){
				var report = personalReportList[index];
				if(id == report.id){
					personalReportList.splice(index,1);
					break;
				}
			}
			LocalStorage.setObject('personalChart',personalReportList);
		},
		updatePersonalReport: function(data){
			for (index in personalReportList){
				var report = personalReportList[index];
				if(report.id == data.id){
					personalReportList[index] = data;
					break;
				}
			}
			LocalStorage.setObject('personalChart',personalReportList);
		},

		//-----------------------------------
		// Social Share
		//-----------------------------------
		setSocialShare: function(data) {
			socialshare = data;
		},
		getSocialShare: function() {
			return socialshare;
		},
		
	}
})

.service('PaymentService',function(){

	var data;

	this.setData = function(value){
		data = value;
	}

	this.getData = function(){
		return data;
	}

})


.factory('Location', function($resource) {
	return $resource('data/location.json', {}, {
				'query':		{method:'GET', isArray:true, cache:true},
	});
})

.factory('Location_v2', function($http) {
	return {				
		query :	function(success) {					 
			var path = 'data/location.json';

			$http({method:'GET',url:path}).success(function(data, status, headers, config){
				success(data);	
			});
		},
	};	
})

.factory('TimeOffset', function($http) {
	return {
		query : function(success) {
			var path = 'data/utc_offset.json';

			$http({method:'GET', url:path}).success(function(data, status, headers, config) {
				success(data);
			});
		},
	};
})

/*
======================================
Translation Service
======================================
*/
.factory('Translation', ['$resource', function($resource) {
	return $resource('data/translations/:code.json',{},{
				'get':{method:'GET', cache:true},
	});
}])

/*
======================================
Social Service
======================================
*/
.factory('Social',function($http, $openFB, LocalStorage){
	$openFB.init({appId: facebookAppId, cordovaOauthCallback: facebookOauth});
	var account = LocalStorage.getObject('social_account');

	return {
		loginWithFacebook: function(successCallback, failCallback){
			var controller = this;

			$openFB.login({scope: 'email', location: false}).then(function(token){
				account = {
					provider: "facebook",
					token: token
				}

				$openFB.api({path: '/me'}).then(function(res){
					console.log('get fb profile success, res:', res);
					account.id = res.id;
					account.name = res.name.replace(/ /g,"");
					LocalStorage.setObject('social_account', account);

					if(successCallback){
						successCallback(token);
					}
				}, function(error){
					console.log('get fb profile error:', error);
					controller.logout();
					if(failCallback){
						failCallback(error);
					}
				});

				/*LocalStorage.setObject('social_account', account);
				if(successCallback){
					successCallback(token);
				}*/
			}, function(error){
				if(failCallback){
					failCallback(error);
				}
			});
		},

		refreshToken: function(successCallback, failCallback){
			var controller = this;
			console.log("facebook refreshToken");
			if(account.provider === "facebook"){
				var params = {
					client_id: facebookAppId,
					client_secret: facebookAppSecret,
					grant_type: 'client_credentials'
				}

				$http.get("https://graph.facebook.com/oauth/access_token", {headers: {Authorization: undefined}, params: params}).then(function(data){
					var tokenParams = {
						input_token: account.token,
						//input_token: "EAAQip0tqAeUBAHZB4TP4NGen96KXSImbcNsnorNOkkXeVtzKD7ZBCUPigZBVlxZBR9GUAyRGmZCq4oZBYVRZC4AP0MOvJ966sXSark0blABHNFnbh29UtoRSzpFnhqwFT0Do4ZBA0Mmv2u0iRACw2ohM7a87XbbuPtGUtW3wAP1GBfoA9b1dN9YA",
						access_token: data.data.split("=")[1]
					}
					$http.get('https://graph.facebook.com/debug_token', {params: tokenParams}).then(function(res){
						console.log('get token info success, res', res);
						var currentDate = new Date();
						var expiryDate = new Date().setTime(res.data.data.expires_at);
						if(!res.data.data.is_valid && expiryDate <= currentDate){
							if(res.data.data.error.subcode === 458 && failCallback){
								failCallback(res.data.data.error);
							} else {
								controller.loginWithFacebook(successCallback, failCallback);
							}
						} else if(res.data.data.is_valid && successCallback){
							successCallback(res);
						} else if(failCallback){
							failCallback(res);
						}
					}, function(error){
						if(failCallback){
							failCallback(error);
						}						
					});
				}, function(error){
					if(failCallback){
						failCallback();
					}
				});			
			}
		},

		logout: function(){
			account = null;
			LocalStorage.setItem('is_social_account', false);	
			LocalStorage.removeObject('social_account');
		},

		getAccount: function(){
			return account;
		}
	}
})

/*
======================================
About Content Manager
======================================
*/
.factory('AboutContentManager',function($ionicLoading,$sce,Airstation,LocalStorage){

	return {
		getAboutContent : function(about,lg_code,success,fail){

			var bGetAboutDataServer = true;

			try{
				if(typeof about[lg_code] !== 'undefined' && about[lg_code] !== null){
					bGetAboutDataServer = false;
				}
				else{
					bGetAboutDataServer = true;
				}
			}
			catch(e){
				bGetAboutDataServer = true;
			}


			if(bGetAboutDataServer === false){
				console.log("About Data Exist In Local");
				//console.log($scope.account);
				success(about);
			}
			else{
				//Get About Content From Server
				console.log("Get About Data From Server");
				Airstation.list(
					{
						app:'hdapp',
						resource:'about',
						lg: lg_code
					},
					function(rpn_data){
						//2.1 Success Handle
						//console.log("Get About Data Success",rpn_data);

						if(typeof about === 'undefined' || about === null){
							about = {};
						}

						_.each(rpn_data,function(item) {
							item.content = $sce.trustAsHtml(item.content);
						});
						
						about[lg_code] = rpn_data;

						LocalStorage.setObject('about', about);

						success(about);
					},
					function(error) {
						//2.1 Fail Handle
						//KBToast.error('failed to get personal chart list');
						about = LocalStorage.getObject('about');
						fail(about);
					}
				);
			}
		}
	};
})

/*
======================================
Report Manager
======================================
*/
.factory('SectionContentManager',function($ionicLoading,$sce,Airstation,LocalStorage){

	return {
		getSectionContent : function(section,lg_code,success,fail){

			var bGetSectionDataServer = true;

			try{
				if(typeof section[lg_code] !== 'undefined' && section[lg_code] !== null){
					bGetSectionDataServer = false;
				}
				else{
					bGetSectionDataServer = true;
				}
			}
			catch(e){
				bGetSectionDataServer = true;
			}


			if(bGetSectionDataServer === false){
				console.log("Section Data Exist In Local");
				//console.log($scope.account);
				success(section);
			}
			else{
				//Get About Content From Server
				console.log("Get Section Data From Server");
				Airstation.list(
					{
						app:'hdapp',
						resource:'section',
						lg: lg_code,
						tut:g_report_tutor
					},
					function(rpn_data){
						//2.1 Success Handle
						//console.log("Get About Data Success",rpn_data);

						if(typeof section === 'undefined' || section === null){
							section = {};
						}

						_.each(rpn_data,function(item) {
							item.free = $sce.trustAsHtml(item.free);
							item.paid = $sce.trustAsHtml(item.paid);
						});
						
						section[lg_code] = rpn_data;

						LocalStorage.setObject('section', section);

						success(section);
					},
					function(error) {
						//2.1 Fail Handle
						//KBToast.error('failed to get personal chart list');
						section = LocalStorage.getObject('section');
						fail(section);
					}
				);
			}
		}
	};
})

/*
======================================
Report Manager
======================================
*/
.factory('ReportManager',function($ionicLoading,Airstation,Datastore,LocalStorage){

	return {
		getProfileChartReport : function(profile,lg_code,success,fail){
			console.log('Get Profile Chart Report Content',lg_code)
			var report = {};
			var bGetReportFromServer = true;
			if(!profile){
				fail();
				return;
			}

			if(profile.hdreport){
				try{
					if(typeof profile.hdreport.content[lg_code] !== 'undefined'){
						bGetReportFromServer = false;
					}
					else{
						bGetReportFromServer = true;
					}
				}
				catch(e){
					bGetReportFromServer = true;
				}
			}

			if(bGetReportFromServer === false){
				console.log('Get Profile Chart Report Content',lg_code, 'exist')
				report = profile.hdreport;
				report.name = profile.real_name;
				report.birth = profile.birth;
				report.city = profile.city;
				report.paid = profile.paid;
				report.gender = profile.gender;
				report.chart_img_url = profile.chart_img_url;
				success(report);
			}
			else{
				//Get Profile Report from server
				console.log('Get Profile Chart Report Content From Server',lg_code)
				//$ionicLoading.show({template:'<i class="icon ion-ios7-reloading font-xxl"></i>'});
				Airstation.get(
					{
						app:'hdapp',
						resource:'profile',
						sub_resource:'report',
						lg:lg_code,
						tut:g_report_tutor
					},
					function(rpn_data){
						//$ionicLoading.hide();

						if(typeof profile.hdreport === 'undefined'){
							profile.hdreport = {};	
						}

						if(typeof profile.hdreport.content === 'undefined'){
							profile.hdreport.content = {};
						}

						profile.hdreport.content[rpn_data.content.lg] = rpn_data.content;
						profile.hdreport.conscious = rpn_data.conscious;
						profile.hdreport.unconscious = rpn_data.unconscious;

						report = profile.hdreport;
						report.name = profile.real_name;
						report.birth = profile.birth;
						report.city = profile.city;
						report.paid = profile.paid;
						report.gender = profile.gender;
						report.chart_img_url = profile.chart_img_url;
						LocalStorage.setObject('profile',profile);

						success(report);
					},
					function(error) {
						//2.1 Fail Handle
						//$ionicLoading.hide();
						fail();
					}
				);
			}   
		},

		getPersonalChartReport :function(report,lg_code,success,fail){
			console.log('Get Personal Chart Report Content',lg_code)
			
			var bGetReportFromServer = true;
			try{
				if(typeof report.content[lg_code] !== 'undefined'){
					bGetReportFromServer = false;
				}
				else{
					bGetReportFromServer = true;
				}
			}
			catch(e){
				bGetReportFromServer = true;
			}
			

			if(bGetReportFromServer === false){
				console.log('Get Personal Chart Report Content',lg_code,' exist')
				success(report);
			}
			else{
				console.log('Get Personal Chart Report Content from server ',lg_code)
				//$ionicLoading.show({template:'<i class="icon ion-ios7-reloading font-xxl"></i>'});
				Airstation.get(
					{
						app:'hdapp',
						resource:'personalchart',
						sub_resource:'report',
						id:report.id,
						lg:lg_code,
						tut:g_report_tutor
					},
					function(rpn_data){
						//$ionicLoading.hide();

						if(typeof report.content === 'undefined'){
							report.content = {};
						}

						report.content[rpn_data.content.lg] = rpn_data.content;
						report.conscious = rpn_data.conscious;
						report.unconscious = rpn_data.unconscious;

						//Update Report
						Datastore.updatePersonalReport(report)
						success(report);

					},
					function(error){
						//2.1 Fail Handle
						//$ionicLoading.hide();
						fail();
					}
				);
			}     
		},

		getCenterImage :function(id,gender,IsDefined){		
			if(id === 1){
				if(IsDefined === false){
					//return "img/report/01_centers/crown_undefined_" + gender + ".jpg"
					return "img/report/01_centers/crown_undefined.png";
				}
				else{
					//return "img/report/01_centers/crown_defined_" + gender + ".jpg"
					return "img/report/01_centers/crown_defined.png";
				}
			}
			else if(id === 2){
				if(IsDefined === false){
					//return "img/report/01_centers/mind_undefined_" + gender + ".jpg"
					return "img/report/01_centers/mind_undefined.png";
				}
				else{
					//return "img/report/01_centers/mind_defined_" + gender + ".jpg"
					return "img/report/01_centers/mind_defined.png";
				}
			}
			else if(id === 3){
				if(IsDefined === false){
					//return "img/report/01_centers/throat_undefined_" + gender + ".jpg"
					return "img/report/01_centers/throat_undefined.png";
				}
				else{
					//return "img/report/01_centers/throat_defined_" + gender + ".jpg"
					return "img/report/01_centers/throat_defined.png";
				}
			}
			else if(id === 4){
				if(IsDefined === false){
					//return "img/report/01_centers/self_undefined_" + gender + ".jpg"
					return "img/report/01_centers/self_undefined.png";
				}
				else{
					//return "img/report/01_centers/self_defined_" + gender + ".jpg"
					return "img/report/01_centers/self_defined.png";
				}
			}
			else if(id === 5){
				if(IsDefined === false){
					//return "img/report/01_centers/heart_undefined_" + gender + ".jpg"
					return "img/report/01_centers/heart_undefined.png";
				}
				else{
					//return "img/report/01_centers/heart_defined_" + gender + ".jpg"
					return "img/report/01_centers/heart_defined.png";
				}
			}
			else if(id === 6){
				if(IsDefined === false){
					//return "img/report/01_centers/spleen_undefined_" + gender + ".jpg"
					return "img/report/01_centers/spleen_undefined.png";
				}
				else{
					//return "img/report/01_centers/spleen_defined_" + gender + ".jpg"
					return "img/report/01_centers/spleen_defined.png";
				}
			}
			else if(id === 7){
				if(IsDefined === false){
					//return "img/report/01_centers/sacral_undefined_" + gender + ".jpg"
					return "img/report/01_centers/sacral_undefined.png";
				}
				else{
					//return "img/report/01_centers/sacral_defined_" + gender + ".jpg"
					return "img/report/01_centers/sacral_defined.png";
				}
			}
			else if(id === 8){
				if(IsDefined === false){
					//return "img/report/01_centers/emotions_undefined_" + gender + ".jpg"
					return "img/report/01_centers/emotions_undefined.png";
				}
				else{
					//return "img/report/01_centers/emotions_defined_" + gender + ".jpg"
					return "img/report/01_centers/emotions_defined.png";
				}
			}
			else if(id === 9){
				if(IsDefined === false){
					//return "img/report/01_centers/root_undefined_" + gender + ".jpg"
					return "img/report/01_centers/root_undefined.png";
				}
				else{
					//return "img/report/01_centers/root_defined_" + gender + ".jpg"
					return "img/report/01_centers/root_defined.png";
				}
			}
			else{
				console.log("Invalid center id",id)
				return ""
			}
		},

		getTypeImage : function(id,gender){
			if(id === 1){
				//return api_domain + "/static/img/hdtype/manifestor_" + gender + ".jpg"
				return api_domain + '/static/img/hdtype/manifestor_F.jpg';
			}
			else if(id === 2){
				//return api_domain + "/static/img/hdtype/generator_" + gender + ".jpg"
				return api_domain + "/static/img/hdtype/generator_F.jpg";
			}
			else if(id === 3){
				//return api_domain + "/static/img/hdtype/projector_" + gender + ".jpg"
				return api_domain + "/static/img/hdtype/projector_F.jpg";
			}
			else if(id === 4){
				//return api_domain + "/static/img/hdtype/reflector_" + gender + ".jpg"
				return api_domain + "/static/img/hdtype/reflector_F.jpg";
			}
			else if(id === 5){
				//return api_domain + "/static/img/hdtype/manifesting_generator_" + gender + ".jpg"
				return api_domain + "/static/img/hdtype/manifesting_generator_F.jpg";
			}
			else{
				console.log("Invalid type id",id)
				return ""
			}
		},

		getAuthorityImage : function(id,gender){
			if(id === 1){
				//return "img/report/04_authority/emotions_" + gender + ".jpg"
				return "img/report/04_authority/CEmotions.png";
			}
			else if(id === 2){
				//return "img/report/04_authority/sacral_" + gender + ".jpg"
				return "img/report/04_authority/CSacral.png";
			}
			else if(id === 3){
				//return "img/report/04_authority/spleen_" + gender + ".jpg"
				return "img/report/04_authority/CSpleen.png";
			}
			else if(id === 4){
				//return "img/report/04_authority/heart_" + gender + ".jpg"
				return "img/report/04_authority/CHeart.png";
			}
			else if(id === 5){
				//return "img/report/04_authority/self_" + gender + ".jpg"
				return "img/report/04_authority/CSelf.png";
			}
			else if(id === 6){
				//None
				//return "img/report/04_authority/none_" + gender + ".jpg"
				return "img/report/04_authority/none.png"
			}
			else{
				console.log("Invalid authority id",id)
				return ""
			}
		},

		getGateImage : function(gate,gender){
			//return "img/report/02_gates/" + gate + "_" + gender + ".jpg"
			return "img/report/02_gates/" + gate + ".png";
		},

		getChannelImage : function(id,gender){
			if(id == 1){
				//return "img/report/03_channels/64_47_" + gender + ".jpg"
				return "img/report/03_channels/64_47.png";
			}
			else if(id == 2){
				//return "img/report/03_channels/61_24_" + gender + ".jpg"
				return "img/report/03_channels/61_24.png";
			}
			else if(id == 3){
				//return "img/report/03_channels/63_4_" + gender + ".jpg"
				return "img/report/03_channels/63_4.png";
			}
			else if(id == 4){
				//return "img/report/03_channels/17_62_" + gender + ".jpg"
				return "img/report/03_channels/17_62.png";
			}
			else if(id == 5){
				//return "img/report/03_channels/43_23_" + gender + ".jpg"
				return "img/report/03_channels/43_23.png";
			}
			else if(id == 6){
				//return "img/report/03_channels/11_56_" + gender + ".jpg"
				return "img/report/03_channels/11_56.png";
			}
			else if(id == 7){
				//return "img/report/03_channels/16_48_" + gender + ".jpg"
				return "img/report/03_channels/16_48.png";
			}
			else if(id == 8){
				//return "img/report/03_channels/20_10_" + gender + ".jpg"
				return "img/report/03_channels/20_10.png";
			}
			else if(id == 9){
				//return "img/report/03_channels/20_57_" + gender + ".jpg"
				return "img/report/03_channels/20_57.png";
			}
			else if(id == 10){
				//return "img/report/03_channels/31_7_" + gender + ".jpg"
				return "img/report/03_channels/31_7.png";
			}
			else if(id == 11){
				//return "img/report/03_channels/8_1_" + gender + ".jpg"
				return "img/report/03_channels/8_1.png";
			}
			else if(id == 12){
				//return "img/report/03_channels/33_13_" + gender + ".jpg"
				return "img/report/03_channels/33_13.png";
			}
			else if(id == 13){
				//return "img/report/03_channels/35_36_" + gender + ".jpg"
				return "img/report/03_channels/35_36.png";
			}
			else if(id == 14){
				//return "img/report/03_channels/12_22_" + gender + ".jpg"
				return "img/report/03_channels/12_22.png";
			}
			else if(id == 15){
				//return "img/report/03_channels/45_21_" + gender + ".jpg"
				return "img/report/03_channels/45_21.png";
			}
			else if(id == 16){
				//return "img/report/03_channels/10_34_" + gender + ".jpg"
				return "img/report/03_channels/10_34.png";
			}
			else if(id == 17){
				//return "img/report/03_channels/15_5_" + gender + ".jpg"
				return "img/report/03_channels/15_5.png";
			}
			else if(id == 18){
				//return "img/report/03_channels/2_14_" + gender + ".jpg"
				return "img/report/03_channels/2_14.png";
			}
			else if(id == 19){
				//return "img/report/03_channels/46_29_" + gender + ".jpg"
				return "img/report/03_channels/46_29.png";
			}
			else if(id == 20){
				//return "img/report/03_channels/25_51_" + gender + ".jpg"
				return "img/report/03_channels/25_51.png";
			}
			else if(id == 21){
				//return "img/report/03_channels/34_57_" + gender + ".jpg"
				return "img/report/03_channels/34_57.png";
			}
			else if(id == 22){
				//return "img/report/03_channels/50_27_" + gender + ".jpg"
				return "img/report/03_channels/50_27.png";
			}
			else if(id == 23){
				//return "img/report/03_channels/42_53_" + gender + ".jpg"
				return "img/report/03_channels/42_53.png";
			}
			else if(id == 24){
				//return "img/report/03_channels/3_60_" + gender + ".jpg"
				return "img/report/03_channels/3_60.png";
			}
			else if(id == 25){
				//return "img/report/03_channels/9_52_" + gender + ".jpg"
				return "img/report/03_channels/9_52.png";
			}
			else if(id == 26){
				//return "img/report/03_channels/6_59_" + gender + ".jpg"
				return "img/report/03_channels/6_59.png";
			}
			else if(id == 27){
				//return "img/report/03_channels/44_26_" + gender + ".jpg"
				return "img/report/03_channels/44_26.png";
			}
			else if(id == 28){
				//return "img/report/03_channels/40_37_" + gender + ".jpg"
				return "img/report/03_channels/40_37.png";
			}
			else if(id == 29){
				//return "img/report/03_channels/32_54_" + gender + ".jpg"
				return "img/report/03_channels/32_54.png";
			}
			else if(id == 30){
				//return "img/report/03_channels/28_38_" + gender + ".jpg"
				return "img/report/03_channels/28_38.png";
			}
			else if(id == 31){
				//return "img/report/03_channels/18_58_" + gender + ".jpg"
				return "img/report/03_channels/18_58.png";
			}
			else if(id == 32){
				//return "img/report/03_channels/49_19_" + gender + ".jpg"
				return "img/report/03_channels/49_19.png";
			}
			else if(id == 33){
				//return "img/report/03_channels/55_39_" + gender + ".jpg"
				return "img/report/03_channels/55_39.png";
			}
			else if(id == 34){
				//return "img/report/03_channels/30_41_" + gender + ".jpg"
				return "img/report/03_channels/30_41.png";
			}
			else if(id == 35){
				//return "img/report/03_channels/20_34_" + gender + ".jpg"
				return "img/report/03_channels/20_34.png";
			}
			else if(id == 36){
				//return "img/report/03_channels/10_57_" + gender + ".jpg"
				return "img/report/03_channels/10_57.png";
			}
			else{
				console.log("Invalid channel id",id)
				return ""
			}
		},
	};
})





